The signs of the factor loadings, as well as of the corresponding
correlations of the latent factors, are switched for each MCMC iteration such
that the factor loadings defined as benchmarks are positive. The sign
switch can only be performed if post.column.switch has been run
before. See section 4.3 (p.42) of CFSHP for more details.
If a latent factor has no benchmarks, or if its benchmark is equal to zero at
some MCMC iteration, then no sign switch is performed on the corresponding
loadings and correlations for this particular factor or MCMC iteration.
Note that in complicated models where the sampler visits several models with
different numbers of latent factors, it may not be relevant to use the
default value of benchmark, as the posterior probabilities that the
factor loadings are different from zero would be computed across models.
Instead, the user might consider finding the highest posterior probability
model first, and use its top elements in each column of the factor loading
matrix as benchmarks to perform the sign switch.